import uuid
from uuid import uuid4

from django.test import TestCase, override_settings
from django.urls import reverse

from core.models import Assembly, Conference, Room

TEST_CONF_ID = uuid.uuid4()


@override_settings(SELECTED_CONFERENCE_ID=TEST_CONF_ID, INTEGRATIONS_BBB=True)
class BBBTest(TestCase):
    def test_MeetingEnded(self):
        conf = Conference(id=TEST_CONF_ID, slug='conf', name='TestConf')
        conf.save()
        assembly = Assembly(name='TestAssembly', slug='asmbly', conference=conf)
        assembly.save()
        room = Room(
            conference=conf,
            assembly=assembly,
            name='Room 1',
            room_type=Room.RoomType.BIGBLUEBUTTON,
            backend_status=Room.BackendStatus.ACTIVE,
            backend_link=str(uuid4()),
            backend_data={'close_secret': 'asdf'},
        )
        room.save()

        self.client.get(
            reverse('api:bbb_meeting_end'),
            {
                'meetingID': room.backend_link,
                'close_secret': 'invalid',
            },
        )
        room.refresh_from_db()
        self.assertEqual(room.backend_status, Room.BackendStatus.ACTIVE)

        self.client.get(
            reverse('api:bbb_meeting_end'),
            {
                'meetingID': room.backend_link,
                'close_secret': 'asdf',
            },
        )
        room.refresh_from_db()
        self.assertEqual(room.backend_status, Room.BackendStatus.INACTIVE)
