from django.forms import ModelForm
from modeltranslation.fields import build_localized_fieldname
from modeltranslation.settings import AVAILABLE_LANGUAGES
from modeltranslation.translator import NotRegistered, translator


class TranslatedFieldsForm(ModelForm):
    def __init_subclass__(cls) -> None:
        res = super().__init_subclass__()

        meta = getattr(cls, 'Meta', None)
        model = getattr(meta, 'model', None)
        if not model:
            return res
        try:
            translation_options = translator.get_options_for_model(model)
        except NotRegistered:
            return res

        fields_to_translate = set(translation_options.get_field_names())

        for attr in (
            'fields',
            'exclude',
            'localized_fields',
        ):
            fields = getattr(meta, attr, None)
            if fields:
                new_fields = []
                for field_name in fields:
                    if field_name not in fields_to_translate:
                        new_fields.append(field_name)
                        continue

                    new_fields.extend(build_localized_fieldname(field_name, lang) for lang in AVAILABLE_LANGUAGES)

                setattr(meta, attr, new_fields)

        return res
