from django.conf import settings
from django_rich.management import RichCommand


class Command(RichCommand):
    def handle(self, *args, **options):
        version_data = settings.APP_VERSION_INFO

        if version_data.get('tag') == 'DEV':
            self.console.print('DEVELOPMENT VERSION', style='yellow bold')
            return

        if version_data.get('ci') is True:
            self.console.print('CI BUILD', style='green bold')

        for k, v in version_data.items():
            if v is None or v == '' or k in ['ci', 'pipeline']:
                continue
            if k == 'tag' and v.startswith('prod-'):
                self.console.print(f'[cyan bold]release[/cyan bold]: {v[5:]:s}')

            self.console.print(f'[cyan bold]{k:s}[/cyan bold]: {v:s}')

        if (pipeline_info := version_data.get('pipeline')) and options.get('verbosity') > 0:
            self.console.print('Pipeline info:', style='bold blue')
            for k, v in pipeline_info.items():
                self.console.print(f'  [blue bold]{k:s}[/blue bold]: {v:s}')
