# Generated by Django 5.1.2 on 2024-10-19 12:38

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models

from core.models import Assembly


def do(apps, schema_editor):
    """ copy assembly log entries into new form """
    ContentType = apps.get_model('contenttypes', 'ContentType')
    AssemblyLogEntry = apps.get_model('core', 'AssemblyLogEntry')  # type: AssemblyLogEntry
    ActivityLogEntry = apps.get_model('core', 'ActivityLogEntry')  # type: ActivityLogEntry
    ct_assembly = ContentType.objects.get_for_model(Assembly)
    for logentry in AssemblyLogEntry.objects.all():
        ActivityLogEntry.objects.create(
            entity_content_type=ct_assembly,
            entity_object_id=logentry.assembly_id,
            timestamp=logentry.timestamp,
            kind=logentry.kind if logentry.kind != 'assembly' else 'entity',
            changes=logentry.changes,
            comment=logentry.comment,
            user_id=logentry.user_id,
            patrolled=None,
        )

def undo(apps, schema_editor):
    """ copy assemblies' log entries into old form"""
    ContentType = apps.get_model('contenttypes', 'ContentType')
    AssemblyLogEntry = apps.get_model('core', 'AssemblyLogEntry')
    ActivityLogEntry = apps.get_model('core', 'ActivityLogEntry')
    ct_assembly = ContentType.objects.get_for_model(Assembly)
    for logentry in ActivityLogEntry.objects.filter(entity_content_type=ct_assembly):
        AssemblyLogEntry.objects.create(
            assembly_id=logentry.entity_object_id,
            timestamp=logentry.timestamp,
            kind=logentry.kind if logentry.kind != 'entity' else 'assembly',
            changes=logentry.changes,
            comment=logentry.comment,
            user=logentry.user,
        )


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('core', '0154_alter_platformuser_display_name_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ActivityLogEntry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('entity_object_id', models.UUIDField()),
                ('timestamp', models.DateTimeField(auto_now_add=True, help_text='ActivityLogEntry__timestamp__help', verbose_name='ActivityLogEntry__timestamp')),
                ('kind', models.CharField(choices=[('sys', 'ActivityLogEntry__kind-sys'), ('message', 'ActivityLogEntry__kind-message'), ('staff', 'ActivityLogEntry__kind-staff'), ('entity', 'ActivityLogEntry__kind-entity')], help_text='ActivityLogEntry__kind__help', max_length=20, verbose_name='ActivityLogEntry__kind')),
                ('context', models.CharField(blank=True, editable=False, help_text='ActivityLogEntry__context__help', null=True, max_length=100, verbose_name='ActivityLogEntry__context')),
                ('changes', models.JSONField(blank=True, help_text='ActivityLogEntry__changes__help', null=True, verbose_name='ActivityLogEntry__changes')),
                ('comment', models.TextField(blank=True, help_text='ActivityLogEntry__comment__help', null=True, verbose_name='ActivityLogEntry__comment')),
                ('entity_content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
                ('user', models.ForeignKey(blank=True, help_text='ActivityLogEntry__user__help', null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='ActivityLogEntry__user')),
                ('patrolled', models.BooleanField(default=False, help_text='ActivityLogEntry__patrolled__help', null=True, verbose_name='ActivityLogEntry__patrolled')),
            ],
            options={
                'verbose_name': 'ActivityLogEntry',
                'verbose_name_plural': 'ActivityLogEntrys',
                'ordering': ['-timestamp'],
            },
        ),
        migrations.RunPython(do, undo, elidable=True),
        migrations.DeleteModel(
            name='AssemblyLogEntry',
        ),
    ]
