import uuid

from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from django.utils.timezone import now

from .users import PlatformUser


class Lock(models.Model):
    uuid = models.UUIDField(primary_key=True, default=uuid.uuid4)
    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.UUIDField()
    content_object = GenericForeignKey('content_type', 'object_id')
    timeout = models.DateTimeField()
    lock_holder = models.ForeignKey(PlatformUser, on_delete=models.CASCADE, related_name='locks')

    class Meta:
        unique_together = [('content_type', 'object_id')]

    @property
    def is_valid(self):
        return self.timeout >= now()
